variable "proxmox_apiuser" {
  type    = string
  default = "packer"
}

variable "proxmox_apitoken" {
  type    = string
  default = "changeme"
}

source "proxmox-iso" "freebsd-14" {
  template_name            = "freebsd-14"
  template_description     = "FreeBSD 14.2, generated on ${timestamp()}"
  vm_id                    = "202"
  boot_wait                = "10s"
  boot_key_interval        = "200ms"
  boot_command             = ["<enter>", "<wait15s>", "<enter><wait1s>", "<enter><wait1s>", "freebsd", "<enter><wait1s>", "<enter><wait1s>", "<enter><wait1s>", "<enter><wait1s>", "<enter><wait1s>", "<enter><wait5s>", "<right><enter><wait1s>", "<enter><wait1s>", "<enter><wait4s>", "<enter><wait1s>", "<enter><wait1s>", " <enter><wait1s>", "<left><enter><wait1s>", "<enter><wait100s>", "packer<enter><wait1s>", "packer<enter><wait1s>", "<down><down><enter><wait1s>", "95<up><enter><wait1s>", "<enter><wait1s>", "<enter><wait1s>", "<enter><wait1s>", "<enter><wait1s>", "<down><down><down> <enter><wait1s>", "<down><down><down><down><down><down><down><down> <enter><wait1s>", "<enter><wait2s>", "<enter><wait1s>", "xadmin<enter>", "Remote admin user<enter>", "<enter>", "<enter>", "wheel<enter>", "<enter>", "<enter>", "<enter>", "<enter>", "<enter>", "<enter>", "<enter>", "<enter>", "packer<enter>", "packer<enter>", "<enter>", "<enter>", "<enter><wait1s>", "<enter><wait1s>", "<left><enter><wait1s>", "pkg install -y qemu-guest-agent sudo<enter><wait30s>", "echo 'xadmin ALL=(ALL:ALL) NOPASSWD:ALL' > /usr/local/etc/sudoers.d/xadmin<enter><wait1s>", "sysrc qemu_guest_agent_enable=YES<enter><wait1s>", "exit<enter><wait1s>", "<enter>"]

  os                       = "other"
  cores                    = "2"
  sockets                  = "1"
  cpu_type                 = "host"
  memory                   = "2048"
  scsi_controller          = "virtio-scsi-single"
  disks {
    disk_size              = "30G"
    storage_pool           = "templates"
    type                   = "scsi"
    format                 = "qcow2"
  }
  network_adapters {
    bridge                 = "vmbr0"
    model                  = "virtio"
  }

  proxmox_url              = "https://kamino.int.metaunix.net:8006/api2/json/"
  insecure_skip_tls_verify = true
  username                 = "${var.proxmox_apiuser}"
  password                 = "${var.proxmox_apitoken}"
  node                     = "kamino"
  pool                     = "Templates"

  boot_iso {
    type                   = "scsi"
    iso_url                = "https://download.freebsd.org/releases/amd64/amd64/ISO-IMAGES/14.2/FreeBSD-14.2-RELEASE-amd64-bootonly.iso"
    iso_checksum           = "sha256:d063e48b81b99005c8097e60377c23fb07e4116c5f0c0b41a5dc368fc4df6bf9"
    iso_download_pve       = true
    iso_storage_pool       = "iso"
    unmount                = true
  }

  ssh_username             = "xadmin"
  ssh_password             = "packer"
  ssh_timeout              = "20m"
}

build {
  sources = ["source.proxmox-iso.freebsd-14"]

  provisioner "shell" {
    script = "scripts/freebsd-install.sh"
  }

  provisioner "file" {
    source      = "scripts/initial-setup.sh"
    destination = "/home/xadmin/initial-setup.sh"
  }
}
